#include "./srcctl.h"
#include <qslider.h>
#include <qlabel.h>
/* 
 *  Constructs a SourceControlWnd which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
SourceControlWnd::SourceControlWnd( QWidget* parent, RecKernel* kern )
    : SourceControl( parent, "Source control", false, 0 ), kernel(kern), scale(1), btn_press(0)
{
    update_size();
    Slider1->setTracking(false);
}

void SourceControlWnd::update_size()
{
    int len=kernel->getVideoLength();
    if(len<1000)
	scale=1;
	else
	scale=len/1000;
    Slider1->setRange(0, len/scale);
    Slider1->setValue(0);
    int pos=kernel->pos();
    char s[256];
    sprintf(s, "frame %d", pos);
    TextLabel3->setText(s);
}
/*  
 *  Destroys the object and frees any allocated resources
 */
SourceControlWnd::~SourceControlWnd()
{
    // no need to delete child widgets, Qt does it all for us
}

/* 
 * public slot
 */
void SourceControlWnd::left_five_frames()
{
    int new_pos=kernel->seek(-5);
    char s[256];
    sprintf(s, "frame %d", new_pos);
    TextLabel3->setText(s);
}
/* 
 * public slot
 */
void SourceControlWnd::left_frame()
{
    int new_pos=kernel->seek(-1);
    char s[256];
    sprintf(s, "frame %d", new_pos);
    TextLabel3->setText(s);
}
/* 
 * public slot
 */
void SourceControlWnd::left_twenty_frames()
{
    int new_pos=kernel->seek(-20);
    char s[256];
    sprintf(s, "frame %d", new_pos);
    TextLabel3->setText(s);
}
/* 
 * public slot
 */
void SourceControlWnd::pos_changed()
{
    int pos=Slider1->value();
    if(!btn_press)
        pos=kernel->seek_pos(pos*scale);
    else
	pos=kernel->pos();
    char s[256];
    sprintf(s, "frame %d", pos);
    TextLabel3->setText(s);
}
/* 
 * public slot
 */
void SourceControlWnd::right_five_frames()
{
    int new_pos=kernel->seek(5);
    char s[256];
    sprintf(s, "frame %d", new_pos);
    TextLabel3->setText(s);
}
/* 
 * public slot
 */
void SourceControlWnd::right_frame()
{
    int new_pos=kernel->seek(1);
//    btn_press=1;
//    Slider1->setValue(new_pos/scale);
//    btn_press=0;
//    int pos=kernel->pos();
    char s[256];
    sprintf(s, "frame %d", new_pos);
    TextLabel3->setText(s);
}
/* 
 * public slot
 */
void SourceControlWnd::right_twenty_frames()
{
    int new_pos=kernel->seek(20);
    char s[256];
    sprintf(s, "frame %d", new_pos);
    TextLabel3->setText(s);
}

#include "srcctl.moc"
#include "srcctl_p.moc"
